@@ -120,9 +120,11 @@ class Payu():
         except requests.exceptions.RequestException as e:
             return {"status": 500, "message": f"Error: {e}"}
 
-    def getPaymentResponse(self, required_data, optionals={}):
+    def getPaymentResponse(self, required_data, optionals=None):
+        if optionals is None:
+            optionals = {}
         if not required_data.get('ids'):
-            raise Exception(f"Parameter id's missing in required_data")
+            raise Exception("Parameter id's missing in required_data")
         required_data['ids'] = "|".join(required_data['ids'])
         response = self.make_request(
             "getPaymentResponse", required_data, optionals=optionals)
@@ -130,13 +132,15 @@ class Payu():
 
     def chkMerchantTxnStatus(self, required_data):
         if not required_data.get('ids'):
-            raise Exception(f"Parameter id's missing in required_data")
+            raise Exception("Parameter id's missing in required_data")
         required_data['ids'] = "|".join(required_data['ids'])
         response = self.make_request(
             "chkMerchantTxnStatus", required_data)
         return response
 
-    def refundPayment(self, required_data, optionals={}):
+    def refundPayment(self, required_data, optionals=None):
+        if optionals is None:
+            optionals = {}
         for key in ['payu_id', 'amount']:
             if not required_data.get(key):
                 raise Exception(
@@ -148,7 +152,7 @@ class Payu():
     def getRefundDetails(self, required_data):
         if not required_data.get('refund_id'):
             raise Exception(
-                f"Mandatory refund_id params missing in required_data")
+                "Mandatory refund_id params missing in required_data")
         response = self.make_request(
             'getRefundDetails', required_data)
         return response
@@ -156,7 +160,7 @@ class Payu():
     def getRefundDetailsByPayment(self, required_data):
         if not required_data.get('payu_id'):
             raise Exception(
-                f"Mandatory payu_id params missing in required_data")
+                "Mandatory payu_id params missing in required_data")
         response = self.make_request(
             'getRefundDetailsByPayment', required_data)
         return response
